==> xwxapt-2.2.tar.bz2: xwxapt-2.2/src/common.h <==
/*
 *  xwxapt: An application to decode APT signals from weather
 *  satellites and produce an image of the weather.
 *
 *  Copyright (C) 2001  Neoklis Kyriazis
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details:
 *
 *  http://www.gnu.org/copyleft/gpl.txt
 */


#ifndef COMMON_H
#define COMMON_H	1

#include <gtk/gtk.h>
#include <string.h>
#include <stdlib.h>

/* Color map data */
typedef struct
{
  /* Pseudo-colorization maps */
  unsigned char
	gray_from[6],	gray_to[6],
	red_from[6],	red_to[6],
	green_from[6],	green_to[6],
	blue_from[6],	blue_to[6];

  int
	white_thld,  /* White (clouds) threshold */
	num_ranges;  /* Number of grayscale ranges */

} color_map_t;

/* Runtime config data */
typedef struct
{
  char
	snd_card[32], /* Sound card name */
	cap_src[32],  /* Capture source  */
	cap_vol[32];  /* Capture volume  */

  int
	channel,	/* ALSA "channel" for use in mixer setup */
	cap_lev;	/* Recording/Capture level */

  guint
	use_chn,		/* Channel in use (frontleft=0, frontright=1 etc) */
	dsp_buf_size,	/* DSP buffer size */
	num_chn;		/* Number of audio channels (2=stereo, 1=mono) */

  /* xwxapt working directory */
  char xwxapt_dir[64];

  int
	default_dur;	/* Default duration of decoding */

  /* Color map data */
  color_map_t
	noaa_A_map,
	meteor_map;

} rc_data_t;

/* Return values */
#define ERROR		1
#define SUCCESS		0

/* Generel definitions for image processing */
#define MAX_FILE_NAME      255 /* Max length for optional filenames */

/* Flow control flags */
#define ICON_SYNC_LOCK          0x0001 /* Sync detector locked icon     */
#define ICON_SYNC_UNLOCK        0x0002 /* Sync detector unlocked icon   */
#define ICON_SYNC_SEARCH        0x0004 /* Sync detector searching icon  */
#define ICON_SYNC_STOPPED       0x0008 /* Sync detector searching icon  */
#define ICON_FLAGS_ALL          0x000f /* All icon flags (for clearing) */
#define ACTION_PROCESS_DSP      0x0010 /* Process images from dsp       */
#define ACTION_PROCESS_FILE     0x0020 /* Process images from file      */
#define ACTION_RECORD_APT       0x0040 /* Record apt signal to file     */
#define ACTION_SETUP_AUDIO      0x0080 /* Run audio level setup func.   */
#define ACTION_SYNC_BUFFER      0x0100 /* Run buffer synchronizing func */
#define ACTION_RATE_ERROR       0x0200 /* Measure dsp sampling rate err */
#define ACTION_FLAGS_ALL        0x03f0 /* All action flags (clearing)   */
#define IMAGE_NORMALIZE         0x0400 /* Histogram normalize wx image  */
#define IMAGE_COLORIZE          0x0800 /* Histogram normalize wx image  */
#define IMAGE_ROTATE            0x1000 /* Rotate wx image 180 degrees   */
#define SOUND_CARD_SETUP        0x2000 /* Sound card has been set up    */
#define START_STOP_TIMER        0x4000 /* Start-Stop timer is set       */

/*---------------------------------------------------------------------*/

/* Function prototypes produced by cproto */
/* callbacks.c */
gboolean Cancel_Timer(gpointer data);
void Error_Dialog(void);
void File_Selection(void);
void Popup_Menu(void);
void Sensitize_Menu_Item(gchar *item_name, gboolean flag);
/* image.c */
void NOAA_Image_Line(unsigned char *image_line, int *max_gray_val);
void Meteor_Image_Line(unsigned char *image_line, int *max_gray_val);
gboolean Dsp_Process_Image(gpointer data);
gboolean File_Process_Image(gpointer data);
void Normalize(unsigned char *image_buffer, int image_size);
void Rotate(unsigned char *image_buffer, int image_size);
void Colorize(unsigned char *image_buffer_a, unsigned char *image_buffer_b,
	int image_size,	unsigned char *colorized_buffer, int map);
void Halfsize_Image(unsigned char *buffer, int width,
	int height, int offset, gboolean color);
void Halfsize_Row(unsigned char *buffer, int width, int line_cnt, int offset);
/* main.c */
int main(int argc, char *argv[]);
void Initialize_Top_Window(void);
/* signal.c */
int Detect_NOAA_Sync(int search_limit);
int Detect_Meteor_Sync(int search_limit);
int Detect_Sync_Train(int search_limit);
int Carrier_Amplitude(short x, short y);
void Set_Sync_Icon( gchar *icon_name );
/* sound.c */
gboolean Setup_Sound_Card(char *mesg, int *error);
void Close_Mixer_Handle(void);
void Close_Capture_Handle(void);
gboolean Setup_Audio_Level(gpointer data);
gboolean Synchronize_Buffer(gpointer data);
gboolean Record_APT_Signal(gpointer data);
gboolean File_Fill_Buffer(void);
gboolean Dsp_Fill_Buffer(void);
gboolean Read_Dsp_Buffer(short *buffer, int buff_size);
gboolean Xrun_Recovery(int error);
/* utils.c */
int Load_Line(char *buff, FILE *pfile, char *messg);
gboolean Load_Colormap(FILE *xwxaptrc, color_map_t *map);
gboolean Load_Config(gpointer data);
void File_Name(char *file_name);
char *Fname(char *fpath);
void Usage(void);
void Show_Message(char *message, char *attr);
void Cleanup(void);
int isFlagSet(int flag);
int isFlagClear(int flag);
gboolean Realloc(unsigned char **buffer, size_t size);
gboolean Open_File(FILE **fp, char *fname, const char *mode);
gboolean File_Image(FILE *fp, const char *type, int width, int height,
					int max_val, unsigned char *buffer);
void SetFlag(int flag);
void ClearFlag(int flag);
void ToggleFlag(int flag);

/*-------------------------------------------------------------------*/

#endif /* End of xwxapt.h */

==> xwxapt-2.4.tar.bz2: xwxapt-2.4/src/common.h <==
/*
 *  xwxapt: An application to decode APT signals from weather
 *  satellites and produce an image of the weather.
 *
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details:
 *
 *  http://www.gnu.org/copyleft/gpl.txt
 */


#ifndef COMMON_H
#define COMMON_H	1

#include <gtk/gtk.h>
#include <string.h>
#include <stdlib.h>

/* Color map data */
typedef struct
{
  /* Pseudo-colorization maps */
  unsigned char
	gray_from[6],	gray_to[6],
	red_from[6],	red_to[6],
	green_from[6],	green_to[6],
	blue_from[6],	blue_to[6];

  int
	white_thld,  /* White (clouds) threshold */
	num_ranges;  /* Number of grayscale ranges */

} color_map_t;

/* Runtime config data */
typedef struct
{
  char
	snd_card[32], /* Sound card name */
	cap_src[32],  /* Capture source  */
	cap_vol[32];  /* Capture volume  */

  int
	channel,	/* ALSA "channel" for use in mixer setup */
	cap_lev;	/* Recording/Capture level */

  guint
	use_chn,		/* Channel in use (frontleft=0, frontright=1 etc) */
	dsp_buf_size,	/* DSP buffer size */
	num_chn;		/* Number of audio channels (2=stereo, 1=mono) */

  /* xwxapt working directory */
  char xwxapt_dir[64];

  int
	window_height,	/* Set default widow height, in sec of image decoding */
	default_dur;	/* Default duration in sec of image decoding */

  /* Color map data */
  color_map_t
	noaa_A_map,
	meteor_map;

} rc_data_t;

/* Return values */
#define ERROR		1
#define SUCCESS		0

/* Generel definitions for image processing */
#define MAX_FILE_NAME      255 /* Max length for optional filenames */

/* Size of char arrays (strings) for error messages etc */
#define MESG_SIZE	128

/* Flow control flags */
#define ICON_SYNC_LOCK          0x0001 /* Sync detector locked icon     */
#define ICON_SYNC_UNLOCK        0x0002 /* Sync detector unlocked icon   */
#define ICON_SYNC_SEARCH        0x0004 /* Sync detector searching icon  */
#define ICON_SYNC_STOPPED       0x0008 /* Sync detector searching icon  */
#define ICON_FLAGS_ALL          0x000f /* All icon flags (for clearing) */
#define ACTION_PROCESS_DSP      0x0010 /* Process images from dsp       */
#define ACTION_PROCESS_FILE     0x0020 /* Process images from file      */
#define ACTION_RECORD_APT       0x0040 /* Record apt signal to file     */
#define ACTION_SETUP_AUDIO      0x0080 /* Run audio level setup func.   */
#define ACTION_SYNC_BUFFER      0x0100 /* Run buffer synchronizing func */
#define ACTION_RATE_ERROR       0x0200 /* Measure dsp sampling rate err */
#define ACTION_FLAGS_ALL        0x03f0 /* All action flags (clearing)   */
#define IMAGE_NORMALIZE         0x0400 /* Histogram normalize wx image  */
#define IMAGE_COLORIZE          0x0800 /* Histogram normalize wx image  */
#define IMAGE_ROTATE            0x1000 /* Rotate wx image 180 degrees   */
#define SOUND_CARD_SETUP        0x2000 /* Sound card has been set up    */
#define START_STOP_TIMER        0x4000 /* Start-Stop timer is set       */

/*---------------------------------------------------------------------*/

/* Function prototypes produced by cproto */
/* callbacks.c */
gboolean Cancel_Timer(gpointer data);
void Error_Dialog(void);
void File_Selection(void);
void Popup_Menu(void);
void Sensitize_Menu_Item(gchar *item_name, gboolean flag);
/* image.c */
void NOAA_Image_Line(unsigned char *image_line, int *max_gray_val);
void Meteor_Image_Line(unsigned char *image_line, int *max_gray_val);
gboolean Dsp_Process_Image(gpointer data);
gboolean File_Process_Image(gpointer data);
void Normalize(unsigned char *image_buffer, int image_size);
void Rotate(unsigned char *image_buffer, int image_size);
void Colorize(unsigned char *image_buffer_a, unsigned char *image_buffer_b,
	int image_size,	unsigned char *colorized_buffer, int map);
void Halfsize_Image(unsigned char *buffer, int width,
	int height, int offset, gboolean color);
void Halfsize_Row(unsigned char *buffer, int width, int line_cnt, int offset);
/* main.c */
int main(int argc, char *argv[]);
void Initialize_Top_Window(void);
/* signal.c */
int Detect_NOAA_Sync(int search_limit);
int Detect_Meteor_Sync(int search_limit);
int Detect_Sync_Train(int search_limit);
int Carrier_Amplitude(short x, short y);
void Set_Sync_Icon( gchar *icon_name );
/* sound.c */
gboolean Setup_Sound_Card(char *mesg, int *error);
void Close_Mixer_Handle(void);
void Close_Capture_Handle(void);
gboolean Setup_Audio_Level(gpointer data);
gboolean Synchronize_Buffer(gpointer data);
gboolean Record_APT_Signal(gpointer data);
gboolean File_Fill_Buffer(void);
gboolean Dsp_Fill_Buffer(void);
gboolean Read_Dsp_Buffer(short *buffer, int buff_size);
gboolean Xrun_Recovery(int error);
/* utils.c */
int Load_Line(char *buff, FILE *pfile, char *messg);
gboolean Load_Colormap(FILE *xwxaptrc, color_map_t *map);
gboolean Load_Config(gpointer data);
void File_Name(char *file_name);
char *Fname(char *fpath);
void Usage(void);
void Show_Message(char *message, char *attr);
void Cleanup(void);
int isFlagSet(int flag);
int isFlagClear(int flag);
gboolean Realloc(unsigned char **buffer, size_t size);
gboolean Open_File(FILE **fp, char *fname, const char *mode);
gboolean File_Image(FILE *fp, const char *type, int width, int height,
					int max_val, unsigned char *buffer);
void SetFlag(int flag);
void ClearFlag(int flag);
void ToggleFlag(int flag);
void Strlcpy(char *dest, const char *src, size_t n);
void Strlcat(char *dest, const char *src, size_t n);

/*-------------------------------------------------------------------*/

#endif /* End of xwxapt.h */
